@@ -116,7 +116,7 @@ class Act(ActBase):
             object_value=[],
             fact_value=[],
             organization=[],
-            source=[],
+            origin=[],
             include_retracted=None,
             before=None,
             after=None,
@@ -512,13 +512,16 @@ Return: List of facts
 """
     facts = []
 
-    my_uri = urllib.parse.urlparse(uri)
+    try:
+        my_uri = urllib.parse.urlparse(uri)
 
-    scheme = my_uri.scheme
-    path = my_uri.path
-    query = my_uri.query
-    addr = my_uri.hostname
-    port = my_uri.port
+        scheme = my_uri.scheme
+        path = my_uri.path
+        query = my_uri.query
+        addr = my_uri.hostname
+        port = my_uri.port
+    except ValueError as e:
+        raise act.api.base.ValidationError(f"Error parsing URI: {uri}: {e}")
 
     if not (scheme and addr):
         raise act.api.base.ValidationError("URI requires both scheme and address part")
